@@ -18,4 +18,7 @@ pub mod strobe;
 pub mod sync_fifo;
 pub mod sync_rom;
 pub mod synchronizer;
+pub mod accum;
 pub mod mac_fir;
+pub mod tristate;
+pub mod bidirectional_bus;
